<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="lv_LV" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Par</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategorija:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Sākt lejupielādi</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Izlaist jaucējkoda pārbaudi</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Izveidot apakšmapi</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrenta pārvaldības režīms:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Visi</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Bez kategorijas</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Pievienot kategoriju...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Dzēst kategoriju</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Dzēst nelietotās kategorijas</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Atsākt torrentus</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Apturēt torrentus</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Dzēst torrentus</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Jauna kategorija</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Labot kategoriju</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Aizvērt qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Katrā rindiņā pa vienai saitei</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Galvenajam atļautajam kopējam augšupielādes ātrumam ir jābūt lielākam par 0 vai arī nekādam.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Galvenajam atļautajam kopējam lejupielādes ātrumam ir jābūt lielākam par 0 vai arī nekādam. </translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatīvajam atļautajam kopējam augšupielādes ātrumam ir jābūt lielākam par 0 vai arī nekādam.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatīvajam atļautajam kopējam lejupielādes ātrumam ir jābūt lielākam par 0 vai arī nekādam.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Atļautajam aktīvo lejupielāžu skaitam jābūt lielākam par -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Atļautajam aktīvo augšupielāžu skaitam jābūt lielākam par -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Atļautajam aktīvo torrentu skaitam jābūt lielākam par -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Atļautajam savienojumu skaitam jābūt lielākam par 0 vai arī atslēgtam. </translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Atļautajam savienojumu skaitam uz katru torrentu jābūt lielākam par 0 vai arī atslēgtam. </translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Atļautajam augšupielādes slotu skaitam uz katru torrentu jābūt lielākam par 0 vai arī atslēgtam.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Neizdevās saglabāt programmas iestatījumus, qBittorrent droši vien nav sasniedzams.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent uz Freenode servera</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nezināms</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Koplietošanas reitinga limitam jābūt starp 0 un 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Augšupielādes ilguma limitam jābūt starp 0 un 525600 minūtēm.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Ienākošo savienojumu portam ir jābūt starp 1 un 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Tālvadības kontroles paneļa portam ir jābūt starp 1 un 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Neizdevās pierakstīties, qBittorrent droši vien nav sasniedzams.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nederīgs lietotājvārds vai parole.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Lietotājvārds</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parole</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Pierakstīties</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Programmas radītāji</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Apstiprināt</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Pievienot</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Augšupielādēt torentus</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Saglabāt failus šeit:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Sīkdatne:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Ievadiet mapi šeit</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Papildus informācija</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informācija par sertifikātiem</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nomainīt saglabāšanas vietu</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Ierobežot augšupielādes ātrumu</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Ierobežot lejupielādes ātrumu</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Pārdēvēt torrentu</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Citā...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Pirmdienās</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Otrdienās</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Trešdienās</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Ceturtdienās</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Piektdienās</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Sestdienās</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Svētdienās</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Iziet</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Lejupielādēt torrentus no to URL vai magnētsaitēm</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Augšupielādēt torrentu</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Vai esat pārliecināts, ka vēlaties izdzēst atlasītos torrentus no Torrentu saraksta?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saglabāt</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent klients nav sasniedzams</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Atļautajam kopējam augšupielādes slotu skaitam ir jābūt lielākam par 0 vai arī nekādam.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nederīgs kategorijas nosaukums:\nLūdzu nelietojiet nekādus īpašos simbolus kategorijas nosaukumā.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Neizdevās izveidot kategoriju</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediģēt</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Brīvās vietas diskā: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Torrenta neaktivitātes taimerim ir jābūt lielākam par 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Saglabāšanas pārvaldība</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent klients ir izslēgts.</translation>
    </message>
    <message>
        <source>Open documentation</source>
        <translation>Atvērt dokumentāciju</translation>
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation>Ieslēgt magnētsaišu atbalstu...</translation>
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation>Neizdevās pievienot Koplietotājus. Pārliecinieties, ka izmantojāt pareizu IP:ports formātu.</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation>Nepieciešams JavaScript! Jums ir jāieslēdz JavaScript, lai Web UI darbotos pareizi.</translation>
    </message>
    <message>
        <source>Name cannot be empty</source>
        <translation>Nosaukumu nevar atstāt tukšu</translation>
    </message>
    <message>
        <source>Name is unchanged</source>
        <translation>Nosaukums palika nemainīts</translation>
    </message>
    <message>
        <source>Failed to update name</source>
        <translation>Neizdevās nosaukuma maiņa</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Rediģēt</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Rīki</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fails</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Palīdzība</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Skats</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Iestatījumi...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Atsākt</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Augšējā rīkjosla</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statusa josla</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Ātrums Nosaukuma joslā</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Ziedot!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Atsākt visus</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Par BitTorrent</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Apturēt</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Apturēt visus</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Pievienot Torrentu failus...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentācija</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Pievienot Torrentu saites...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Jā</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nē</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Atļautais kopējais augšupielādes ātrums</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Atļautais kopējais lejupielādes ātrums</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Vai esat pārliecināts, ka vēlaties aizvērt qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[L: %1, A: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternatīvie atļautie ātrumi</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Meklētājs</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Meklēt torrentu sarakstā...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Meklētājs</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Torrenti</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation>Novietot augstāk sarakstā</translation>
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation>Novietot augstāk sarakstā</translation>
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation>Novietot saraksta apakšā</translation>
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation>Novietot saraksta apakšā</translation>
    </message>
    <message>
        <source>Top of Queue</source>
        <translation>Novietot saraksta augšā</translation>
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation>Novietot zemāk sarakstā</translation>
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation>Novietot zemāk sarakstā</translation>
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation>Novietot saraksta augšā</translation>
    </message>
    <message>
        <source>Your browser does not support this feature</source>
        <translation>Jūsu interneta pārlūks neatbalsta šo iespēju</translation>
    </message>
    <message>
        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
        <translation>Lai izmantotu šo iespēju, WebUI ir jāatver caur HTTPS</translation>
    </message>
    <message>
        <source>Connection status: Firewalled</source>
        <translation>Savienojuma statuss: Aiz ugunsmūra</translation>
    </message>
    <message>
        <source>Connection status: Connected</source>
        <translation>Savienojuma statuss: Savienots</translation>
    </message>
    <message>
        <source>Alternative speed limits: Off</source>
        <translation>Alternatīvie ielādes ātrumi: Nē</translation>
    </message>
    <message>
        <source>Download speed icon</source>
        <translation>Lejupielādes ātruma ikona</translation>
    </message>
    <message>
        <source>Connection status</source>
        <translation>Savienojuma statuss</translation>
    </message>
    <message>
        <source>Alternative speed limits: On</source>
        <translation>Alternatīvie ielādes ātrumi: Jā</translation>
    </message>
    <message>
        <source>Upload speed icon</source>
        <translation>Augšupielādes ātruma ikona</translation>
    </message>
    <message>
        <source>Connection status: Disconnected</source>
        <translation>Savienojuma statuss: Nav savienots</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Lejupielādes</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Savienojums</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Ātrums</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Tālvadība</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Valoda</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Saskarnes valoda: </translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>E-pasta paziņojums par lejupielādes pabeigšanu</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Pēc torrenta lejupielādes pabeigšanas, palaist programmu</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP filtrēšana</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Uzstādīt laiku Alternatīvo atļauto ātrumu pielietošanai</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrentu saraksts</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Automātiski pievienot šos trakerus jaunajiem torrentiem:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Tālvadības kontroles panelis (Web UI)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP adrese:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Servera domēni:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>HTTP vietā izmantot HTTPS</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Izlaist pierakstīšanos uz saimnieka datora</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Izlaist pierakstīšanos klientiem, kuri atrodas apakštīklu IP baltajā sarakstā</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Atjaunināt manu dinamiskā domēna nosaukumu</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Glabāt nepabeigtos failus šeit:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Izveidot .torrent failu kopijas šeit:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Izveidot .torrent failu kopijas pabeigtajiem torrentiem šeit:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Rezervēt vietu uz diska jaunajiem failiem</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Pievienot .!qB galotni nepabeigtajiem failiem</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Automātiski pievienot torrentus no:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP serveris:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Šim serverim ir nepieciešams šifrēts savienojums (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Pierakstīšanās</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Lietotājvārds:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parole:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Protokola izvēle:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP un μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Portu iestatījumi</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Ports, kuru izmanto ienākošajiem savienojumiem:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Lietot mana rūtera UPnP / NAT-PMP portu pāradresāciju</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Automātiski izvēlēties un nomainīt portu pie qBittorrent ieslēgšanas</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Savienojumu ierobežojumi</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Atļautais savienojumu skaits katram torrentam:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Atļautais kopējais savienojumu skaits:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Atļautais augšupielādes slotu skaits katram torrentam:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Atļautais kopējais augšupielādes slotu skaits:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Starpniekserveris</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Lietot:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Nevienu)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Adrese:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Ports:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Izmantot starpniekserveri koplietotāju savienojumiem</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Lietot starpniekserveri tikai torrentiem</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Filtra atrašanās vieta (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manuāli bloķētās IP adreses...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Pielietot trakeriem</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Galvenie atļautie kopējie ātrumi</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Augšupielāde: </translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Lejupielāde:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternatīvie atļautie kopējie ātrumi</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>No:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Uz:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Kad:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Katru dienu.</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Darbdienās</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Nedēļas nogalēs</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Ielādes ātrumu ierobežojumu iestatījumi</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Pielietot ātruma ierobežojums tikai transporta izmaksām</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Pielietot ierobežojumus µTP protokolam</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Privātums</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Ieslēgt DHT (necentralizēto tīklu), lai atrastu vēl vairāk koplietotājus</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Ieslēgt datu apmaiņu koplietotāju starpā (PeX), lai atrastu vairāk koplietotājus</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Ieslēgt Vietējo koplietotāju meklēšanu, lai atrastu vēl vairāk koplietotājus</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Šifrēšanas režīms:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Pieprasīt šifrēšanu</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Atslēgt šifrēšanu</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Ieslēgt anonīmo režīmu</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Atļautais aktīvo lejupielāžu skaits:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Atļautais aktīvo augšupielāžu skaits:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Atļautais kopējais aktīvo torrentu skaits:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Neiekļaut šajās robežās lēnos torrentus.</translation>
    </message>
    <message>
        <source>then</source>
        <translation>tad</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Lietot UPnP / NAT-PMP lai pāradresētu portu manā maršrutētājā</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Sertifikāts</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Atslēga:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Reģistrēties</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domēna vārds:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Nodrošinātie parametri (reģistrjūtīgi):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrent faila nosaukums</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategorija</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Satura ceļš (tāpat kā saknes ceļš daudz-failu torrentam)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Saknes ceļš (pirmā torrent apakšdirektorija ceļš)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Saglabāšanas vieta</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Failu skaits</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrenta izmērs (baitos)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Pašreizējais trakeris</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Jaucējkods</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Padoms: Lai izvairītos no teksta sadalīšanās, ja lietojat atstarpes, ievietojiet parametru pēdiņās (piemēram, "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Tālvadības paneļa lietotājvārdam jāsatur vismaz 3 rakstzīmes.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Tālvadības paneļa parolei jāsatur vismaz 6 rakstzīmes.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minūtes</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Ieslēgt aizsardzību pret clickjacking</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Ieslēgt aizsardzību pret Cross-Site Request Forgery (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Izdzēst .torrent failu pēc tā pievienošanas</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Nepārsniedz Lejupielādes ātrumu:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Nepārsniedz Auģsupielādes ātrumu:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Mainīt patreizējo paroli</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automātiski</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Lietot citu Tālvadības paneļa saskarni</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Noklusētā saglabāšanas vieta:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Saskarnes failu atrašanās vieta nevar tikt atstāta tukša.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Neuzsākt lejupielādi automātiski</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Pārslēgt torrentu Manuālajā režīmā</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Mainot torrenta kategoriju:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Pārvietot ietekmētos torrentus</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Pielietot ierobežojumus koplietotājiem LAN tīklā</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 nozīmē neirobežots</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Pārvietot torrentu</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Mainot noklusējuma saglabāšanas vietu:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Ieslēgt Hosta header apstiprināšanu</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Drošība</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Mainot kategorijas saglabāšanas vietu:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Izveidot apakšmapi torrentiem, kas satur vairākus failus</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekundes</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Pārslēgt ietekmētos torrentus Manuālajā režīmā</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Failu atrašanās vieta:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuāli</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrentu neaktivitātes skaitītājs:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Noklusētais torrentu pārvaldības režīms:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Pievienojot torrentu</translation>
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation>Brīdinājums: Šī parole netiek glabāta šifrētā veidā</translation>
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload rate based</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation>%G: Birkas (atdalītas ar komatu)</translation>
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation>Ieslēgt torrentu super-augšupielādi</translation>
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation>Priekšroku TCP</translation>
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Anti-leech</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation>Izmantot OS kešatmiņu</translation>
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation>Kad reitings sasniedz</translation>
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation>Kad augšupielādes laiks sasniedz</translation>
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation>Atļaut vairākus savienojumus no vienas IP adreses</translation>
    </message>
    <message>
        <source>File pool size:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Any interface</source>
        <translation>Automātiski</translation>
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation>Vienmēr atjaunināt datus ar visiem trakeriem visās grupās</translation>
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation>Iebūvētā trakera ports:</translation>
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation>Piesaistīt papildu IP adresi (nepieciešams restarts)</translation>
    </message>
    <message>
        <source>Fastest upload</source>
        <translation>Ātrākā augšupielāde</translation>
    </message>
    <message>
        <source>Pause torrent</source>
        <translation>Apturēt torrentu</translation>
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation>Izdzēst torrentu un failus</translation>
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation>qBittorrent sadaļa</translation>
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation>libtorrent sadaļa</translation>
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation>Izejošie porti (Min) [0: Atslēgts]:</translation>
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation>IP adrese, kuru paziņot trakeriem (nepieciešams restarts):</translation>
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation>Pārbaudīt torrentus pēc ielādes pabeigšanas:</translation>
    </message>
    <message>
        <source>Allow encryption</source>
        <translation>Atļaut šifrēšanu</translation>
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache:</source>
        <translation>Diska kešatmiņa:</translation>
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation>Ieslēgt iebūvēto trakeri:</translation>
    </message>
    <message>
        <source>Remove torrent</source>
        <translation>Dzēst torrentu</translation>
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation>Izejošie porti (Maks.) [0: Atslēgts]</translation>
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>s</source>
        <translation> s</translation>
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation>Diska kešatmiņas derīguma intervāls</translation>
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Fixed slots</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Advanced</source>
        <translation>Papildus</translation>
    </message>
    <message>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation>Augšupielādes ierobežojumi</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>Round-robin</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation>Interneta savienojums (nepieciešams restarts) </translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation>Progresa datu saglabāšanas intervāls</translation>
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation>Vienmēr atjaunināt datus ar visiem trakeriem grupā</translation>
    </message>
    <message>
        <source>Session timeout:</source>
        <translation>Sesijas noildze:</translation>
    </message>
    <message>
        <source>Resolve peer countries:</source>
        <translation>Rādīt koplietotāju valstis:</translation>
    </message>
    <message>
        <source>ban for:</source>
        <translation>liegt piekļuvi uz:</translation>
    </message>
    <message>
        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Stop tracker timeout:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Ban client after consecutive failures:</source>
        <translation>Liegt piekļuvi pēc atkārtotiem mēģinājumiem:</translation>
    </message>
    <message>
        <source>Enable cookie Secure flag (requires HTTPS)</source>
        <translation>Ieslēgt sīkdatņu Secure Flag (nepieciešams HTTPS)</translation>
    </message>
    <message>
        <source>UPnP lease duration [0: Permanent lease]:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Header: value pairs, one per line</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Add custom HTTP headers</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Ports</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Karogi</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Savienojums</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klients</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Progress</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Lejupielādes ātrums</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Augšupielādes ātrums</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Lejupielādēti</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Augšupielādēti</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Koplietotāja progress</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Faili</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation>Nobloķēt koplietotāju</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation>Vai esat pārliecināts, ka vēlāties nobloķēt atlasītos koplietotājus?</translation>
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation>Kopēt IP un portu</translation>
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation>Pievienot jaunu koplietotāju...</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>Valsts/Apgabals</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normāla</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Augsta</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Augstākā</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation>Jaukta</translation>
    </message>
    <message>
        <source>Do not download</source>
        <translation>Nelejupielādēt</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Vispārīgi</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trakeri</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Koplietotāji</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP avoti</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Saturs</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Lejupielādēti:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Koplietošanas dati</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aktīvs jau:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Aptuvenais ielādes laiks:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Augšupielādēti:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Devēji:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Lejupielādes ātrums:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Augšupielādes ātrums:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Ņēmēji:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Lejupielādes robeža:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Augšupielādes robeža:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Izmesti:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Savienojumi:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informācija</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentārs:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Koplietošanas reitings:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Kontakts ar trakeri pēc:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Pēdējo reizi koplietots</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Kopējais izmērs:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Daļiņas</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Izveidots ar:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Pievienots:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Pabeigts:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Izveidots:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrenta jaucējkods:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Saglabāšanas vieta:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nekad</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (ielādētas %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 šajā sesijā)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 atļauti)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 kopā)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 vidējais)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Lejupielādes robeža:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Augšupielādes robeža:</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritāte</translation>
    </message>
    <message>
        <source>Filter files...</source>
        <translation>Meklēt failos...</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Pārdēvēt...</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Uzraudzītā mape</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Ignorēt saglabāšanas vietu</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Uzraudzītā mape</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Noklusējuma saglabāšanas vieta</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistika</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Lietotāja statistika</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Kešatmiņa:</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Pievienotie koplietotāji:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Kopējais koplietošanas reitings:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Kopējais lejupielādes daudzums:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Izmesti šajā sesijā:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Kopējais augšupielādes daudzums:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Kopējais bufera izmērs:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Veiktspējas statistika</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Kešatmiņas rakstīšanas noslodze:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Kešatmiņas lasīšanas noslodze:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 serveri</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Visi (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Lejupielādē (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Augšupielādē (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Pabeigti (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Atsākti (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Apturēti (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktīvi (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Neaktīvi (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Kļūdaini (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Visi (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Lejupielādē (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Augšupielādē (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Pabeigti (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Apturēti (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Atsākti (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktīvi (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Neaktīvi (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Kļūdaini (%1)</translation>
    </message>
    <message>
        <source>Stalled Uploading (%1)</source>
        <translation>Apstājušās Augšupielādes (%1)</translation>
    </message>
    <message>
        <source>Stalled Downloading (%1)</source>
        <translation>Apstājušās Lejupielādes (%1)</translation>
    </message>
    <message>
        <source>Stalled Downloading (0)</source>
        <translation>Apstājušās Lejupielādes (0)</translation>
    </message>
    <message>
        <source>Stalled (0)</source>
        <translation>Apstājušies (0)</translation>
    </message>
    <message>
        <source>Stalled Uploading (0)</source>
        <translation>Apstājušās Augšupielādes (0)</translation>
    </message>
    <message>
        <source>Stalled (%1)</source>
        <translation>Apstājušies (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Izmērs</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Pabeigti</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Statuss</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Devēji</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Ņēmēji</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Lejupielādes ātrums</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Augšupielādes ātrums</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Reitings</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Apt. Ielādes laiks</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorija</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Birkas</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Pievienots</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Pabeigts</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Trakeris</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Lejupielādes robeža</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Augšupielādes robeža</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Lejupielādēti</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Augšupielādēti</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Lejupielādēti šajā sesijā</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Augšupielādēti šajā sesijā</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Atlikuši</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aktīvs jau</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Saglabāšanas vieta</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Pabeigti</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Reitinga robeža</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Pēdējo reizi koplietots</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Pēdējā aktivitāte</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Kopējais izmērs</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Pieejamība</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Statuss</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Koplietotāji</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Ziņojums</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Lejupielādēti</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Trakera adrese:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Atjaunina...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Strādā</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Atslēgts</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Vēl nav savienots</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nav zināms</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Devēji</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Nestrādā</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopēt trakera adresi</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Pievienot jaunu trakeri...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Rediģēt trakeri adresi...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Trakera rediģēšana</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Ņēmēji</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Noņemt trakeri</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Atlikuši</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Pieejamība</translation>
    </message>
    <message>
        <source>Tier</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Lejupielādes prioritāte</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progress</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Izmērs</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Trakeru pievienošanas logs</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Saraksts ar trakeriem, kurus pievienot (katrā rindā pa vienam):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>pirms %1</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Nodrošinām brīvo vietu</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Apturēts</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Pabeigts</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Pārvieto</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[P] Augšupielādēšana</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Augšupielādē</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>Ierindots</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Kļūdaini</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[P] Lejupielādē</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Lejupielādējam metadatus</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Pārbauda</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Trūkst faili</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Ierindots pārbaudei</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Lejupielādē</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Pārbaudām atsākšanas datus</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Apstājies</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Statuss</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorijas</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Birkas</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Torrenta lejupielādes ātruma ierobežošana</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Torrenta augšupielādes ātruma ierobežošana</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pārdēvēt</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Atsākt</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Piespiedu atsākšana</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Apturēt</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Ierobežot koplietošanas reitingu...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Ierobežot augšupielādes ātrumu...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Ierobežot lejupielādes ātrumu...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Pārvietot augšup</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Pārvietot lejup</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Novietot saraksta augšgalā</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Novietot saraksta apakšā</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Nomainīt failu atrašanās vietu...</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Vispirms ielādēt pirmās un pēdējās daļiņas</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automātiska torrentu pārvaldība</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategorija</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Jaunu...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Atiestatīt</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Piespiedu pārbaude</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Super-augšupielādēšanas režīms</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Pārdēvēt...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Lejupielādēt secīgā kārtībā</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Piespiedu pārbaude</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Jauna kategorija</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Atrašanās vieta</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Jaunais nosaukums</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Nomainīt saglabāšanas vietu</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Piespiedu datu atjaunināšana ar trakeriem</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Labot kategoriju</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Saglabāšanas vieta</translation>
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation>Atdalīt birkas ar komatu:</translation>
    </message>
    <message>
        <source>Add Tags</source>
        <translation>Pievienot birkas</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Birkas</translation>
    </message>
    <message>
        <source>Magnet link</source>
        <translation>Magnētsaite</translation>
    </message>
    <message>
        <source>Hash</source>
        <translation>Jaucējkods:</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Noņemt visas</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopēt</translation>
    </message>
    <message>
        <source>Queue</source>
        <translation>Rinda</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Pievienot birku...</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Torrenta augšupielādes/lejupielādes reitinga ierobežošana</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Lietot galvenos uzstādījumus</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Neierobežot</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Reitinga robeža</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>reitings</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minūtes</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Dzēšanas apstiprināšana</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Izdzēst failus arī uz cietā diska</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Dzēšanas apstiprināšana - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Lejupielādēt no saitēm</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lejupielādēt</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Pievienot torrentu saites</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1st %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2st</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Nezināms</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Saglabāšanas vieta ir tukša</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Spraudņa vieta:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>Interneta adrese vai vieta datorā</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Instalēt spraudni</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Apstiprināt</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Devēji:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Visi spraudņi</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Izmērs:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Pārtraukt</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Meklēt</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Meklētāju spraudņi...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Visas kategorijas</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Meklēt:</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Rezultāti (parādīti</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Meklēt rezultātos</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Tikai torrentu nosaukumos</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Ieslēgtie spraudņi</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>no</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Visur</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Atinstalēt</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Instalēt jaunu spraudni</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Jaunus meklētāja spraudņus varat dabūt šeit:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Aizvērt</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Ieinstalētie meklētāju spraudņi:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Ieslēgts</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Uzmanību: Pārliecinieties, ka ievērojat jūsu valsts autortiesību likumus, pirms lejupielādējat šajos meklētājos atrastos torrentus.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Meklēt atjauninājumus</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Meklētāju spraudņi</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Izmērs</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Ņēmēji</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Meklētājs</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Devēji</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Adrese</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Ieslēgts</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versija</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Jā</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nē</translation>
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Add Peers</source>
        <translation>Koplietotāju pievienošana</translation>
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation>Saraksts ar jaunajiem koplietotājiem (katrā rindā pa vienam):</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Apstiprināt</translation>
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation>Paraugs: IPv4:ports / [IPv6]:ports</translation>
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation>Jauna birka</translation>
    </message>
    <message>
        <source>Add tag...</source>
        <translation>Pievienot birku...</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Dzēst torrentus</translation>
    </message>
    <message>
        <source>Tag:</source>
        <translation>Birka:</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Apturēt torrentus</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Atsākt torrentus</translation>
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation>Dzēst nelietotās birkas</translation>
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation>Nederīgs birkas nosaukums</translation>
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Dzēst birku</translation>
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation>Visi</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Bez birkas</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation>Par kļūmēm:</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Par</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forums:</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation>E-pasts:</translation>
    </message>
    <message>
        <source>Current maintainer</source>
        <translation>Pašreizējais uzturētājs</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Mājaslapa:</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Grieķija</translation>
    </message>
    <message>
        <source>Special Thanks</source>
        <translation>Īpašs paldies</translation>
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Moderns BitTorrent klients programmēts C++ valodā, veidots uz Qt toolkit un libtorrent-rasterbar bāzes.</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Vārds:</translation>
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation>Par qBittorrent</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Tulkotāji</translation>
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation>Šī qBittorrent versija tika uzbūvēta, izmantojot šīs bibliotēkas:</translation>
    </message>
    <message>
        <source>Nationality:</source>
        <translation>Nacionalitāte:</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Autori</translation>
    </message>
    <message>
        <source>Software Used</source>
        <translation>Programmatūra</translation>
    </message>
    <message>
        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
        <translation>Bezmaksas "Valsts pēc IP" kompaktā datubāze (IP to Country Lite) no DB-IP tiek izmantota, lai pēc IP adresēm noteiktu un parādītu jums koplietotāju valstis. Datubāze ir licencēta zem Attiecinājums 4.0 Starptautisks (CC BY 4.0)</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation>Visas adreses</translation>
    </message>
    <message>
        <source>All IPv6 addresses</source>
        <translation>Visas IPv6 adreses</translation>
    </message>
    <message>
        <source>All IPv4 addresses</source>
        <translation>Visas IPv4 adreses</translation>
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation>Kopēt</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lejupielādēt</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nosaukumu</translation>
    </message>
    <message>
        <source>Description page URL</source>
        <translation>Apraksta lapas adresi</translation>
    </message>
    <message>
        <source>Open description page</source>
        <translation>Atvērt torrenta apraksta lapu</translation>
    </message>
    <message>
        <source>Download link</source>
        <translation>Lejupielādes adresi</translation>
    </message>
</context>
<context>
    <name>TorrentContentTreeView</name>
    <message>
        <source>Renaming</source>
        <translation>Pārdēvēšana</translation>
    </message>
    <message>
        <source>New name:</source>
        <translation>Jaunais nosaukums:</translation>
    </message>
</context>
</TS>